package nu.zoom.dsl.jte;

import gg.jte.CodeResolver;
import gg.jte.ContentType;
import gg.jte.TemplateEngine;
import gg.jte.TemplateOutput;
import gg.jte.output.FileOutput;
import gg.jte.resolve.DirectoryCodeResolver;
import nu.zoom.dsl.ast.DocumentNode;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

public class Generator {
    private final Path templatesDir ;
    private final DocumentNode data;
    private final Path outputDir ;
    private final TemplateEngine templateEngine;

    public Generator(Path templatesDir, DocumentNode data, Path outputDir) {
        this.templatesDir = Objects.requireNonNull(templatesDir);
        this.data = Objects.requireNonNull(data);
        this.outputDir = Objects.requireNonNull(outputDir);
        this.templateEngine = TemplateEngine.create(
                new DirectoryCodeResolver(templatesDir),
                ContentType.Plain
        );
    }

    public List<Path> generate() throws IOException {
        List<Path> templates = Files.list(templatesDir).filter(p -> p.toString().endsWith(".jte")).toList() ;
        ArrayList<Path> out = new ArrayList<>();
        for (Path template : templates) {
            // TODO file ending
            Path outpath = outputDir.resolve(template.getFileName());
            this.templateEngine.render(template.getFileName().toString(), this.data, new FileOutput(outpath));
            out.add(outpath);
        }
        return out ;
    }
}
